==> western-world-3.0.629.tgz: package/src/defs/flag.js <==
export const flagAnimated = `
    <symbol id="flagAnimated" viewBox="0 0 8192 8192">
        <style>
            #animate-flag {display: none}
            .animated #animate-flag {display: block}
            #non-animate-flag {display: block}
            .animated #non-animate-flag {display: none}
            #animate-flag, #non-animate-flag {fill: #FF4848}
        </style>
        <path id="animate-flag" d="M63.3,71.7c0.7,0.5,1.3,1,2,1.5c0.7,0.5,1.4,1,2.1,1.5c26.4,18.7,49.9,14.8,74.1,9.1 c29-6.8,59.2-16.3,97.2,6.8c-45.1-9.1-62.6,29.4-93.9,50.7c-18.3,12.4-41.2,19-77.1,6.8c-0.7-0.3-1.5-0.5-2.3-0.8 s-1.7-0.6-2.5-0.9L63.3,71.7z" >
            <animate 
                accumulate="none" 
                additive="replace" 
                attributeName="d" 
                attributeType="auto" 
                begin="0s" 
                calcMode="spline" 
                dur="1s" 
                fill="remove" 
                id="animate2988" 
                keySplines="0.05 0 0.95 1; 0.05 0 0.95 1" 
                keyTimes="0;0.45;1" 
                repeatCount="indefinite" 
                restart="always" 
                values="
                    m 63.336312,71.691314 c 0.657874,0.516957 1.313808,1.019644 1.967858,1.50837 0.703219,0.525466 1.40426,1.034792 2.103196,1.528361 26.43933,18.670713 49.865554,14.793317 74.144764,9.059598 29.00007,-6.848587 59.21709,-16.345568 97.23924,6.769806 -45.13915,-9.123362 -62.64783,29.422791 -93.92824,50.721071 -18.25376,12.42866 -41.19726,18.98383 -77.057915,6.76518 -0.745319,-0.25394 -1.496217,-0.516 -2.252768,-0.78629 -0.821847,-0.29361 -1.650366,-0.59693 -2.485651,-0.9101 z;
                    m 63.336312,71.691314 c 0.659866,-0.117195 1.31518,-0.23111 1.965989,-0.341782 35.868039,-6.099477 58.054249,-2.347781 74.692589,5.207181 28.76555,13.061556 41.01008,50.467247 78.20427,43.150867 1.88702,-0.3712 3.82051,-0.81132 5.80443,-1.32596 -1.25386,1.41625 -2.4928,2.77815 -3.71749,4.08799 -27.3116,29.21061 -55.84873,15.6355 -76.52492,12.17591 -20.55607,-3.43948 -41.51945,-7.24243 -77.781612,10.26588 -0.960107,0.46356 -1.930939,0.94206 -2.912772,1.43591 z;
                    m 63.336312,71.691314 c 27.630309,21.711854 51.837238,18.253668 76.877978,12.410458 28.75963,-6.711002 58.61912,-16.568046 96.02807,4.947797 0.48339,0.278028 0.96805,0.561294 1.45399,0.849874 0.36429,0.216339 0.72929,0.435664 1.09502,0.658006 -0.44532,-0.09001 -0.88796,-0.175375 -1.32795,-0.256166 -0.4257,-0.07817 -0.84893,-0.152052 -1.26972,-0.221707 -42.82316,-7.088795 -60.3299,29.618914 -90.4756,50.610194 -19.17784,13.35405 -43.47084,20.34745 -82.651304,5.65754 z
            ">
            </animate>
        </path>
        <path id="non-animate-flag" d="M63.3,71.7c0.7,0.5,1.3,1,2,1.5c0.7,0.5,1.4,1,2.1,1.5c26.4,18.7,49.9,14.8,74.1,9.1 c29-6.8,59.2-16.3,97.2,6.8c-45.1-9.1-62.6,29.4-93.9,50.7c-18.3,12.4-41.2,19-77.1,6.8c-0.7-0.3-1.5-0.5-2.3-0.8 s-1.7-0.6-2.5-0.9L63.3,71.7z" />
    </symbol>
`;

==> western-world-3.0.683.tgz: package/src/defs/flag.js <==
export const flagAnimated = `
    <symbol id="flagAnimated" viewBox="0 0 8192 8192">
        <style>
            #animate-flag {display: none}
            .animated #animate-flag {display: block}
            #non-animate-flag {display: block}
            .animated #non-animate-flag {display: none}
            #animate-flag, #non-animate-flag {fill: var(--flag-color, #FF4848)}
        </style>
        <path id="animate-flag" d="M63.3,71.7c0.7,0.5,1.3,1,2,1.5c0.7,0.5,1.4,1,2.1,1.5c26.4,18.7,49.9,14.8,74.1,9.1 c29-6.8,59.2-16.3,97.2,6.8c-45.1-9.1-62.6,29.4-93.9,50.7c-18.3,12.4-41.2,19-77.1,6.8c-0.7-0.3-1.5-0.5-2.3-0.8 s-1.7-0.6-2.5-0.9L63.3,71.7z" >
            <animate 
                accumulate="none" 
                additive="replace" 
                attributeName="d" 
                attributeType="auto" 
                begin="0s" 
                calcMode="spline" 
                dur="1s" 
                fill="remove" 
                id="animate2988" 
                keySplines="0.05 0 0.95 1; 0.05 0 0.95 1" 
                keyTimes="0;0.45;1" 
                repeatCount="indefinite" 
                restart="always" 
                values="
                    m 63.336312,71.691314 c 0.657874,0.516957 1.313808,1.019644 1.967858,1.50837 0.703219,0.525466 1.40426,1.034792 2.103196,1.528361 26.43933,18.670713 49.865554,14.793317 74.144764,9.059598 29.00007,-6.848587 59.21709,-16.345568 97.23924,6.769806 -45.13915,-9.123362 -62.64783,29.422791 -93.92824,50.721071 -18.25376,12.42866 -41.19726,18.98383 -77.057915,6.76518 -0.745319,-0.25394 -1.496217,-0.516 -2.252768,-0.78629 -0.821847,-0.29361 -1.650366,-0.59693 -2.485651,-0.9101 z;
                    m 63.336312,71.691314 c 0.659866,-0.117195 1.31518,-0.23111 1.965989,-0.341782 35.868039,-6.099477 58.054249,-2.347781 74.692589,5.207181 28.76555,13.061556 41.01008,50.467247 78.20427,43.150867 1.88702,-0.3712 3.82051,-0.81132 5.80443,-1.32596 -1.25386,1.41625 -2.4928,2.77815 -3.71749,4.08799 -27.3116,29.21061 -55.84873,15.6355 -76.52492,12.17591 -20.55607,-3.43948 -41.51945,-7.24243 -77.781612,10.26588 -0.960107,0.46356 -1.930939,0.94206 -2.912772,1.43591 z;
                    m 63.336312,71.691314 c 27.630309,21.711854 51.837238,18.253668 76.877978,12.410458 28.75963,-6.711002 58.61912,-16.568046 96.02807,4.947797 0.48339,0.278028 0.96805,0.561294 1.45399,0.849874 0.36429,0.216339 0.72929,0.435664 1.09502,0.658006 -0.44532,-0.09001 -0.88796,-0.175375 -1.32795,-0.256166 -0.4257,-0.07817 -0.84893,-0.152052 -1.26972,-0.221707 -42.82316,-7.088795 -60.3299,29.618914 -90.4756,50.610194 -19.17784,13.35405 -43.47084,20.34745 -82.651304,5.65754 z
            ">
            </animate>
        </path>
        <path id="non-animate-flag" d="M63.3,71.7c0.7,0.5,1.3,1,2,1.5c0.7,0.5,1.4,1,2.1,1.5c26.4,18.7,49.9,14.8,74.1,9.1 c29-6.8,59.2-16.3,97.2,6.8c-45.1-9.1-62.6,29.4-93.9,50.7c-18.3,12.4-41.2,19-77.1,6.8c-0.7-0.3-1.5-0.5-2.3-0.8 s-1.7-0.6-2.5-0.9L63.3,71.7z" />
    </symbol>
`;
